@@ -10,26 +10,15 @@
 #ifndef _PCRE_H
 #define _PCRE_H
 
-#define PCRE_MAJOR "3"
-#define PCRE_MINOR "1"
-#define PCRE_DATE  "09-Feb-2000"
+#define PCRE_MAJOR 3
+#define PCRE_MINOR 4
+#define PCRE_DATE  22-Aug-2000
+
+#define SUPPORT_UTF8
 
 /* Have to include stdlib.h in order to ensure that size_t is defined;
 it is needed here for malloc. */
 
-/* MAC detection, and #ifndef MAC, added by SRET because Mac doesn't have
-   <sys/types.h> */
-#ifdef __MWERKS__
-#undef MAC
-#define MAC
-#endif
-#ifdef __BEOS__
-#undef MAC
-#endif
-#ifndef MAC
-#include <sys/types.h>
-#endif
-
 #include <stdlib.h>
 
 /* Allow for C++ users */
@@ -51,6 +40,7 @@ extern "C" {
 #define PCRE_NOTEOL          0x0100
 #define PCRE_UNGREEDY        0x0200
 #define PCRE_NOTEMPTY        0x0400
+#define PCRE_UTF8            0x0800
 
 /* Exec-time and get-time error codes */
 
@@ -87,10 +77,10 @@ extern void  (*pcre_free)(void *);
 /* Functions */
 
 extern pcre *pcre_compile(const char *, int, const char **, int *,
-  const unsigned char *);
-extern int pcre_exec(const pcre *, const pcre_extra *, const char *,
-  int, int, int, int *, int);
-extern int pcre_fullinfo(const pcre *, const pcre_extra *, int, void *);
+              const unsigned char *);
+extern int  pcre_exec(const pcre *, const pcre_extra *, const char *,
+              int, int, int, int *, int);
+extern int  pcre_fullinfo(const pcre *, const pcre_extra *, int, void *);
 
 #ifdef __cplusplus
 }  /* extern "C" */
